@@ -14,7 +14,8 @@
 
 *Please note: This library is in a very early stage. I am trying my best to stabilize the APIs and improving the overall quality. APIs may change at this time.*
 
-Plotters is drawing library designed for rendering figures, plots, and charts, in pure rust. Plotters supports various types of backends, including bitmap, vector graph and WebAssembly.
+Plotters is drawing library designed for rendering figures, plots, and charts, in pure rust. Plotters supports various types of backends,
+including bitmap, vector graph, piston window and WebAssembly.
 
 ## Gallery
 
@@ -67,12 +68,51 @@ Plotters is drawing library designed for rendering figures, plots, and charts, i
     </div>
 </div>
 
+
+<div class="galleryItem">
+    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/evcxr_animation.gif">
+        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/evcxr_animation.gif" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Jupyter Support
+    </div>
+</div>
+
+<div class="galleryItem">
+    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/plotters-piston.gif">
+        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/plotters-piston.gif" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Realtime Rendering
+        <a href="https://github.com/38/plotters/tree/master/examples/piston-demo">[code]</a>
+    </div>
+</div>
+
+## Table of Content
+  * [Gallery](#gallery)
+  * [Quick Start](#quick-start)
+  * [Trying with Jupyter evcxr Kernel Interactively](#trying-with-jupyter-evcxr-kernel-interactively)
+  * [Plotting in Rust](#plotting-in-rust)
+  * [Plotting on HTML5 canvas with WASM Backend](#plotting-on-html5-canvas-with-wasm-backend)
+  * [What types of figure are supported?](#what-types-of-figure-are-supported-)
+  * [Concepts by examples](#concepts-by-examples)
+    + [Drawing Backends](#drawing-backends)
+    + [Drawing Area](#drawing-area)
+    + [Elements](#elements)
+    + [Composable Elements](#composable-elements)
+    + [Chart Context](#chart-context)
+  * [Misc](#misc)
+    + [Development Version](#development-version)
+    + [Reducing Depending Libraries && Turning Off Backends](#reducing-depending-libraries----turning-off-backends)
+
+
+
 ## Quick Start
 
 To use Plotters, you can simply add Plotters into your `Cargo.toml`
 ```toml
 [depedencies]
-plotters = "^0.1.14"
+plotters = "^0.2.0"
 ```
 
 And the following code draws a quadratic function. `src/main.rs`,
@@ -109,6 +149,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 
 ![](https://raw.githubusercontent.com/38/plotters/master/examples/outputs/0.png)
 
+
 ## Trying with Jupyter evcxr Kernel Interactively
 
 Plotters now supports integrate with `evcxr` and is able to interactively drawing plots in Jupyter Notebook.
@@ -150,7 +191,7 @@ figure
 
 <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/evcxr_animation.gif" width="450px"></img>
 
-## Motivation of Plotting in Rust
+## Plotting in Rust
 
 Rust is a perfect language for data visualization. Although there are many mature visualization libraries in many different languages.
 But Rust is one of the best languages fits the need.
@@ -170,6 +211,15 @@ figure rendering code into your application handling a huge amount of data and v
 * **WebAssembly Support** Rust is one of few the language with the best WASM support. Plotting in Rust could be
 very useful for visualization on a web page and would have a huge performance improvement comparing to Javascript.
 
+## Plotting on HTML5 canvas with WASM Backend
+
+Plotters currently supports backend that uses the HTML5 canvas. To use the WASM support, you can simply use
+`CanvasBackend` instead of other backend and all other API remains the same!
+
+There's a small demo for Plotters + WASM under `examples/wasm-demo` directory of this repo.
+To play with the deployed version, follow this [link](https://plumberserver.com/plotters-wasm-demo/index.html).
+
+
 ## What types of figure are supported?
 
 Plotters is not limited to any specific type of figure.
@@ -180,14 +230,6 @@ Currently, we support line series, point series, candlestick series, and histogr
 And the library is designed to be able to render multiple figure into a single image.
 But Plotter is aimed to be a platform that is fully extendable to support any other types of figure.
 
-## Plotting on HTML5 canvas
-
-Plotters currently supports backend that uses the HTML5 canvas. To use the WASM support, you can simply use
-`CanvasBackend` instead of other backend and all other API remains the same!
-
-There's a small demo for Plotters + WASM under `examples/wasm-demo` directory of this repo.
-To play with the deployed version, follow this [link](https://plumberserver.com/plotters-wasm-demo/index.html).
-
 ## Concepts by examples
 
 ### Drawing Backends
